pub enum TileNodeKind {
Leaf {
prev_indices: Vec<PrimitiveDependencyIndex>,
curr_indices: Vec<PrimitiveDependencyIndex>,
dirty_tracker: u64,
frames_since_modified: usize,
},
Node {
children: Vec<TileNode>,
},
}Expand description
Details for a node in a quadtree that tracks dirty rects for a tile.
Variants
Leaf
Fields

prev_indices: Vec<PrimitiveDependencyIndex>The index buffer of primitives that affected this tile previous frame

curr_indices: Vec<PrimitiveDependencyIndex>The index buffer of primitives that affect this tile on this frame
Node